/*******************************************************************************
* File Name: j1FreeRTOS_ClkStats.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_j1FreeRTOS_ClkStats_H)
#define CY_CLOCK_j1FreeRTOS_ClkStats_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void j1FreeRTOS_ClkStats_Start(void) ;
void j1FreeRTOS_ClkStats_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void j1FreeRTOS_ClkStats_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void j1FreeRTOS_ClkStats_StandbyPower(uint8 state) ;
void j1FreeRTOS_ClkStats_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 j1FreeRTOS_ClkStats_GetDividerRegister(void) ;
void j1FreeRTOS_ClkStats_SetModeRegister(uint8 modeBitMask) ;
void j1FreeRTOS_ClkStats_ClearModeRegister(uint8 modeBitMask) ;
uint8 j1FreeRTOS_ClkStats_GetModeRegister(void) ;
void j1FreeRTOS_ClkStats_SetSourceRegister(uint8 clkSource) ;
uint8 j1FreeRTOS_ClkStats_GetSourceRegister(void) ;
#if defined(j1FreeRTOS_ClkStats__CFG3)
void j1FreeRTOS_ClkStats_SetPhaseRegister(uint8 clkPhase) ;
uint8 j1FreeRTOS_ClkStats_GetPhaseRegister(void) ;
#endif /* defined(j1FreeRTOS_ClkStats__CFG3) */

#define j1FreeRTOS_ClkStats_Enable()                       j1FreeRTOS_ClkStats_Start()
#define j1FreeRTOS_ClkStats_Disable()                      j1FreeRTOS_ClkStats_Stop()
#define j1FreeRTOS_ClkStats_SetDivider(clkDivider)         j1FreeRTOS_ClkStats_SetDividerRegister(clkDivider, 1u)
#define j1FreeRTOS_ClkStats_SetDividerValue(clkDivider)    j1FreeRTOS_ClkStats_SetDividerRegister((clkDivider) - 1u, 1u)
#define j1FreeRTOS_ClkStats_SetMode(clkMode)               j1FreeRTOS_ClkStats_SetModeRegister(clkMode)
#define j1FreeRTOS_ClkStats_SetSource(clkSource)           j1FreeRTOS_ClkStats_SetSourceRegister(clkSource)
#if defined(j1FreeRTOS_ClkStats__CFG3)
#define j1FreeRTOS_ClkStats_SetPhase(clkPhase)             j1FreeRTOS_ClkStats_SetPhaseRegister(clkPhase)
#define j1FreeRTOS_ClkStats_SetPhaseValue(clkPhase)        j1FreeRTOS_ClkStats_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(j1FreeRTOS_ClkStats__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define j1FreeRTOS_ClkStats_CLKEN              (* (reg8 *) j1FreeRTOS_ClkStats__PM_ACT_CFG)
#define j1FreeRTOS_ClkStats_CLKEN_PTR          ((reg8 *) j1FreeRTOS_ClkStats__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define j1FreeRTOS_ClkStats_CLKSTBY            (* (reg8 *) j1FreeRTOS_ClkStats__PM_STBY_CFG)
#define j1FreeRTOS_ClkStats_CLKSTBY_PTR        ((reg8 *) j1FreeRTOS_ClkStats__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define j1FreeRTOS_ClkStats_DIV_LSB            (* (reg8 *) j1FreeRTOS_ClkStats__CFG0)
#define j1FreeRTOS_ClkStats_DIV_LSB_PTR        ((reg8 *) j1FreeRTOS_ClkStats__CFG0)
#define j1FreeRTOS_ClkStats_DIV_PTR            ((reg16 *) j1FreeRTOS_ClkStats__CFG0)

/* Clock MSB divider configuration register. */
#define j1FreeRTOS_ClkStats_DIV_MSB            (* (reg8 *) j1FreeRTOS_ClkStats__CFG1)
#define j1FreeRTOS_ClkStats_DIV_MSB_PTR        ((reg8 *) j1FreeRTOS_ClkStats__CFG1)

/* Mode and source configuration register */
#define j1FreeRTOS_ClkStats_MOD_SRC            (* (reg8 *) j1FreeRTOS_ClkStats__CFG2)
#define j1FreeRTOS_ClkStats_MOD_SRC_PTR        ((reg8 *) j1FreeRTOS_ClkStats__CFG2)

#if defined(j1FreeRTOS_ClkStats__CFG3)
/* Analog clock phase configuration register */
#define j1FreeRTOS_ClkStats_PHASE              (* (reg8 *) j1FreeRTOS_ClkStats__CFG3)
#define j1FreeRTOS_ClkStats_PHASE_PTR          ((reg8 *) j1FreeRTOS_ClkStats__CFG3)
#endif /* defined(j1FreeRTOS_ClkStats__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define j1FreeRTOS_ClkStats_CLKEN_MASK         j1FreeRTOS_ClkStats__PM_ACT_MSK
#define j1FreeRTOS_ClkStats_CLKSTBY_MASK       j1FreeRTOS_ClkStats__PM_STBY_MSK

/* CFG2 field masks */
#define j1FreeRTOS_ClkStats_SRC_SEL_MSK        j1FreeRTOS_ClkStats__CFG2_SRC_SEL_MASK
#define j1FreeRTOS_ClkStats_MODE_MASK          (~(j1FreeRTOS_ClkStats_SRC_SEL_MSK))

#if defined(j1FreeRTOS_ClkStats__CFG3)
/* CFG3 phase mask */
#define j1FreeRTOS_ClkStats_PHASE_MASK         j1FreeRTOS_ClkStats__CFG3_PHASE_DLY_MASK
#endif /* defined(j1FreeRTOS_ClkStats__CFG3) */

#endif /* CY_CLOCK_j1FreeRTOS_ClkStats_H */


/* [] END OF FILE */
