/*******************************************************************************
* File Name: j1HY28B_iCtrl_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "j1HY28B_iCtrl.h"

/* Check for removal by optimization */
#if !defined(j1HY28B_iCtrl_Sync_ctrl_reg__REMOVED)

static j1HY28B_iCtrl_BACKUP_STRUCT  j1HY28B_iCtrl_backup = {0u};

    
/*******************************************************************************
* Function Name: j1HY28B_iCtrl_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void j1HY28B_iCtrl_SaveConfig(void) 
{
    j1HY28B_iCtrl_backup.controlState = j1HY28B_iCtrl_Control;
}


/*******************************************************************************
* Function Name: j1HY28B_iCtrl_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void j1HY28B_iCtrl_RestoreConfig(void) 
{
     j1HY28B_iCtrl_Control = j1HY28B_iCtrl_backup.controlState;
}


/*******************************************************************************
* Function Name: j1HY28B_iCtrl_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void j1HY28B_iCtrl_Sleep(void) 
{
    j1HY28B_iCtrl_SaveConfig();
}


/*******************************************************************************
* Function Name: j1HY28B_iCtrl_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void j1HY28B_iCtrl_Wakeup(void)  
{
    j1HY28B_iCtrl_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
