//=====================================================================
//	FreeRTOS_Demo - main.c
//=====================================================================

#define	THIS_IS_MAIN_APPLICATION

#include "main.h"

void Hardware_Setup();
void FreeRTOS_Setup();
bool CreateTasks();

int main()
{
	Hardware_Setup();
	FreeRTOS_Setup();

	// create tasks & start-up the FreeRTOS scheduler
	if (CreateTasks()) vTaskStartScheduler();
	
//	LCD_Position( 1, 0 );
//	LCD_PrintString("Start Scheduler ");

	while (true)
    {
    }
}

//---------------------------------------------------------------------
//
//	Hardware_Setup() - setup all of our hardware
//
//---------------------------------------------------------------------

void Hardware_Setup()
{
	j1HY28B_Start(&HY28B_Ctrl, &HY28B_j1GFX_Ctrl, 0, j1GFX_ROTATE_N, 0xff0000, NULL);
	
	StatsCount_Start();
}

//---------------------------------------------------------------------
//
//	FreeRTOS_Setup() - do all the hardware setups for FreeRTOS
//
//---------------------------------------------------------------------

void FreeRTOS_Setup()
{
	/* Port layer functions that need to be copied into the vector table. */
	extern void xPortPendSVHandler( void );
	extern void xPortSysTickHandler( void );
	extern void vPortSVCHandler( void );
	extern cyisraddress CyRamVectors[];

	/* Install the OS Interrupt Handlers. */
	CyRamVectors[ 11 ] = ( cyisraddress ) vPortSVCHandler;
	CyRamVectors[ 14 ] = ( cyisraddress ) xPortPendSVHandler;
	CyRamVectors[ 15 ] = ( cyisraddress ) xPortSysTickHandler;
}

//---------------------------------------------------------------------
//	CreateTasks() - create all the tasks & global mutexes
//---------------------------------------------------------------------

bool CreateTasks()
{
	unsigned portBASE_TYPE	i;
	TASK_CREATE_TABLE		const *tctPtr;
	portBASE_TYPE			result;
	
	for (i = 0, tctPtr = taskCreateTable; i < taskCreateTableSize; i++, tctPtr++)
	{
		result = xTaskCreate(tctPtr->pvTaskCode, tctPtr->cTaskName, tctPtr->usStackDepth, NULL, tctPtr->uxPriority, &taskHandleTable[i]);
		if (result != pdPASS) return false;
	}
	
	if (Mutexes_Start() == false) return false;
	
	return true;
}

//---------------------------------------------------------------------
//	StatsCount_Start()
//---------------------------------------------------------------------

void StatsCount_Start()
{
}

//---------------------------------------------------------------------
//	StatsCount_Read()
//---------------------------------------------------------------------

uint32 StatsCount_Read()
{
	uint32	count;
	
	count = 0x12345678;
	
	return count;
}

//---------------------------------------------------------------------
//	vApplicationStackOverflowHook()
//---------------------------------------------------------------------

void vApplicationStackOverflowHook( TaskHandle_t pxTask, signed char *pcTaskName )
{
	/* The stack space has been execeeded for a task, considering allocating more. */
	taskDISABLE_INTERRUPTS();
	while (true) {}
}

//---------------------------------------------------------------------
//	vApplicationMallocFailedHook()
//---------------------------------------------------------------------

void vApplicationMallocFailedHook( void )
{
	/* The heap space has been execeeded. */
	taskDISABLE_INTERRUPTS();
	while (true) {}
}

